==> zio-aws-lexmodelsv2_2.12-6.20.103.1-sources.jar: zio/aws/lexmodelsv2/model/StartTestExecutionResponse.scala <==
package zio.aws.lexmodelsv2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lexmodelsv2.model.primitives.{Timestamp, Id}
import scala.jdk.CollectionConverters._
final case class StartTestExecutionResponse(
    testExecutionId: Optional[Id] = Optional.Absent,
    creationDateTime: Optional[Timestamp] = Optional.Absent,
    testSetId: Optional[Id] = Optional.Absent,
    target: Optional[zio.aws.lexmodelsv2.model.TestExecutionTarget] =
      Optional.Absent,
    apiMode: Optional[zio.aws.lexmodelsv2.model.TestExecutionApiMode] =
      Optional.Absent,
    testExecutionModality: Optional[
      zio.aws.lexmodelsv2.model.TestExecutionModality
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse = {
    import StartTestExecutionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
      .builder()
      .optionallyWith(
        testExecutionId.map(value => Id.unwrap(value): java.lang.String)
      )(_.testExecutionId)
      .optionallyWith(
        creationDateTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationDateTime)
      .optionallyWith(
        testSetId.map(value => Id.unwrap(value): java.lang.String)
      )(_.testSetId)
      .optionallyWith(target.map(value => value.buildAwsValue()))(_.target)
      .optionallyWith(apiMode.map(value => value.unwrap))(_.apiMode)
      .optionallyWith(testExecutionModality.map(value => value.unwrap))(
        _.testExecutionModality
      )
      .build()
  }
  def asReadOnly
      : zio.aws.lexmodelsv2.model.StartTestExecutionResponse.ReadOnly =
    zio.aws.lexmodelsv2.model.StartTestExecutionResponse.wrap(buildAwsValue())
}
object StartTestExecutionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.StartTestExecutionResponse =
      zio.aws.lexmodelsv2.model.StartTestExecutionResponse(
        testExecutionId.map(value => value),
        creationDateTime.map(value => value),
        testSetId.map(value => value),
        target.map(value => value.asEditable),
        apiMode.map(value => value),
        testExecutionModality.map(value => value)
      )
    def testExecutionId: Optional[Id]
    def creationDateTime: Optional[Timestamp]
    def testSetId: Optional[Id]
    def target: Optional[zio.aws.lexmodelsv2.model.TestExecutionTarget.ReadOnly]
    def apiMode: Optional[zio.aws.lexmodelsv2.model.TestExecutionApiMode]
    def testExecutionModality
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionModality]
    def getTestExecutionId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("testExecutionId", testExecutionId)
    def getCreationDateTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationDateTime", creationDateTime)
    def getTestSetId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("testSetId", testSetId)
    def getTarget: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.TestExecutionTarget.ReadOnly
    ] = AwsError.unwrapOptionField("target", target)
    def getApiMode
        : ZIO[Any, AwsError, zio.aws.lexmodelsv2.model.TestExecutionApiMode] =
      AwsError.unwrapOptionField("apiMode", apiMode)
    def getTestExecutionModality
        : ZIO[Any, AwsError, zio.aws.lexmodelsv2.model.TestExecutionModality] =
      AwsError.unwrapOptionField("testExecutionModality", testExecutionModality)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
  ) extends zio.aws.lexmodelsv2.model.StartTestExecutionResponse.ReadOnly {
    override val testExecutionId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.testExecutionId())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Id(value))
    override val creationDateTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDateTime())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Timestamp(value))
    override val testSetId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.testSetId())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Id(value))
    override val target
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionTarget.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.target())
        .map(value => zio.aws.lexmodelsv2.model.TestExecutionTarget.wrap(value))
    override val apiMode
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionApiMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.apiMode())
        .map(value =>
          zio.aws.lexmodelsv2.model.TestExecutionApiMode.wrap(value)
        )
    override val testExecutionModality
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionModality] =
      zio.aws.core.internal
        .optionalFromNullable(impl.testExecutionModality())
        .map(value =>
          zio.aws.lexmodelsv2.model.TestExecutionModality.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
  ): zio.aws.lexmodelsv2.model.StartTestExecutionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lexmodelsv2_3-6.20.162.2-sources.jar: zio/aws/lexmodelsv2/model/StartTestExecutionResponse.scala <==
package zio.aws.lexmodelsv2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lexmodelsv2.model.primitives.{Timestamp, Id}
import scala.jdk.CollectionConverters.*
final case class StartTestExecutionResponse(
    testExecutionId: Optional[Id] = Optional.Absent,
    creationDateTime: Optional[Timestamp] = Optional.Absent,
    testSetId: Optional[Id] = Optional.Absent,
    target: Optional[zio.aws.lexmodelsv2.model.TestExecutionTarget] =
      Optional.Absent,
    apiMode: Optional[zio.aws.lexmodelsv2.model.TestExecutionApiMode] =
      Optional.Absent,
    testExecutionModality: Optional[
      zio.aws.lexmodelsv2.model.TestExecutionModality
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse = {
    import StartTestExecutionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
      .builder()
      .optionallyWith(
        testExecutionId.map(value => Id.unwrap(value): java.lang.String)
      )(_.testExecutionId)
      .optionallyWith(
        creationDateTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationDateTime)
      .optionallyWith(
        testSetId.map(value => Id.unwrap(value): java.lang.String)
      )(_.testSetId)
      .optionallyWith(target.map(value => value.buildAwsValue()))(_.target)
      .optionallyWith(apiMode.map(value => value.unwrap))(_.apiMode)
      .optionallyWith(testExecutionModality.map(value => value.unwrap))(
        _.testExecutionModality
      )
      .build()
  }
  def asReadOnly
      : zio.aws.lexmodelsv2.model.StartTestExecutionResponse.ReadOnly =
    zio.aws.lexmodelsv2.model.StartTestExecutionResponse.wrap(buildAwsValue())
}
object StartTestExecutionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.StartTestExecutionResponse =
      zio.aws.lexmodelsv2.model.StartTestExecutionResponse(
        testExecutionId.map(value => value),
        creationDateTime.map(value => value),
        testSetId.map(value => value),
        target.map(value => value.asEditable),
        apiMode.map(value => value),
        testExecutionModality.map(value => value)
      )
    def testExecutionId: Optional[Id]
    def creationDateTime: Optional[Timestamp]
    def testSetId: Optional[Id]
    def target: Optional[zio.aws.lexmodelsv2.model.TestExecutionTarget.ReadOnly]
    def apiMode: Optional[zio.aws.lexmodelsv2.model.TestExecutionApiMode]
    def testExecutionModality
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionModality]
    def getTestExecutionId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("testExecutionId", testExecutionId)
    def getCreationDateTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationDateTime", creationDateTime)
    def getTestSetId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("testSetId", testSetId)
    def getTarget: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.TestExecutionTarget.ReadOnly
    ] = AwsError.unwrapOptionField("target", target)
    def getApiMode
        : ZIO[Any, AwsError, zio.aws.lexmodelsv2.model.TestExecutionApiMode] =
      AwsError.unwrapOptionField("apiMode", apiMode)
    def getTestExecutionModality
        : ZIO[Any, AwsError, zio.aws.lexmodelsv2.model.TestExecutionModality] =
      AwsError.unwrapOptionField("testExecutionModality", testExecutionModality)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
  ) extends zio.aws.lexmodelsv2.model.StartTestExecutionResponse.ReadOnly {
    override val testExecutionId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.testExecutionId())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Id(value))
    override val creationDateTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDateTime())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Timestamp(value))
    override val testSetId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.testSetId())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Id(value))
    override val target
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionTarget.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.target())
        .map(value => zio.aws.lexmodelsv2.model.TestExecutionTarget.wrap(value))
    override val apiMode
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionApiMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.apiMode())
        .map(value =>
          zio.aws.lexmodelsv2.model.TestExecutionApiMode.wrap(value)
        )
    override val testExecutionModality
        : Optional[zio.aws.lexmodelsv2.model.TestExecutionModality] =
      zio.aws.core.internal
        .optionalFromNullable(impl.testExecutionModality())
        .map(value =>
          zio.aws.lexmodelsv2.model.TestExecutionModality.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.StartTestExecutionResponse
  ): zio.aws.lexmodelsv2.model.StartTestExecutionResponse.ReadOnly =
    new Wrapper(impl)
}
